@@ -30,12 +30,16 @@
 // Media
 #include "av1rtppacketizer.hpp"
 #include "h264rtppacketizer.hpp"
+#include "h264rtpdepacketizer.hpp"
 #include "h265rtppacketizer.hpp"
 #include "mediahandler.hpp"
 #include "plihandler.hpp"
+#include "rembhandler.hpp"
+#include "pacinghandler.hpp"
 #include "rtcpnackresponder.hpp"
 #include "rtcpreceivingsession.hpp"
 #include "rtcpsrreporter.hpp"
 #include "rtppacketizer.hpp"
+#include "rtpdepacketizer.hpp"
 
 #endif // RTC_ENABLE_MEDIA
